@@ -35,7 +35,7 @@ def md2docx(markdown_file: str="", output_file: str="", **kwargs):
     import pypandoc, os, shutil
     from agentmake import getOpenCommand
     if not shutil.which("pandoc"):
-        print("Tool 'pandoc' is not found on your system! Read https://pandoc.org/installing.html for installation.")
+        print("Required tool 'pandoc' is not found on your system! Read https://pandoc.org/installing.html for installation.")
         return ""
     docx_file = output_file if output_file else markdown_file.replace(".md", ".docx")
     pypandoc.convert_file(markdown_file, 'docx', outputfile=docx_file)
