@@ -22,7 +22,7 @@ def perplexica_anthropic(messages, **kwargs):
             i["role"] = "human"
             history.append(i)
 
-    api_url = f"{PERPLEXICA_HOST}:{PERPLEXICA_BACKEND_PORT}/api/search" 
+    api_url = f"{PERPLEXICA_HOST}:{PERPLEXICA_PORT}/api/search" 
     headers = {"Content-Type": "application/json"}
     # references:
     # https://github.com/ItzCrazyKns/Perplexica/blob/master/docs/API/SEARCH.md
@@ -53,9 +53,7 @@ def perplexica_anthropic(messages, **kwargs):
         answer = response_json["message"]
         sources = response_json["sources"]
         
-        print("```answer")
-        print(answer)
-        print("```\n\n```sources")
+        print(f"{answer}\n\n```")
 
         for index, i in enumerate(sources):
             if "metadata" in i:
