@@ -3,7 +3,7 @@ TOOL_SYSTEM = ""
 TOOL_SCHEMA = {}
 TOOL_DESCRIPTION = """Read text aloud in Cantonese with Edge TTS utility."""
 
-def speak_cantonese_termux_tts(messages, **kwargs):
+def speak_edge_tts_cantonese(messages, **kwargs):
     from agentmake.utils.media import generate_edge_tts_audio, playAudioFile
     content = messages[-1].get("content", "")
     audioFile = generate_edge_tts_audio(content, edgettsVoice="zh-HK-HiuGaaiNeural")
@@ -11,4 +11,4 @@ def speak_cantonese_termux_tts(messages, **kwargs):
     playAudioFile(audioFile)
     return ""
 
-TOOL_FUNCTION = speak_cantonese_termux_tts
\ No newline at end of file
+TOOL_FUNCTION = speak_edge_tts_cantonese
\ No newline at end of file
